@@ -161,6 +161,14 @@ class ChatNavPage(Adw.Bin):
             row_to_update = self.message_list.get_row_at_index(x)
             row_to_update.update_ui()
 
+    def update_ui_periodic(self) -> bool:
+        if hasattr(self, 'message_list'):
+            self.logger.debug("Update node UI")
+            self.update_ui()
+            return GLib.SOURCE_CONTINUE
+        else:
+            return GLib.SOURCE_REMOVE
+
     """
     Since we added a sort function, the rows will automatically sort when
     appended, no need to manually specifiy
@@ -259,3 +267,4 @@ class ChatNavPage(Adw.Bin):
         self.message_bar.set_nav_page(self)
         self.message_list.set_sort_func(sort_func=self._sort_func)
         self.logger = app.logger
+        GLib.timeout_add(60000, self.update_ui_periodic)
