@@ -21,7 +21,12 @@ from gi.repository import Adw
 from gi.repository import Gtk
 from gi.repository import Shumate
 
+import datetime
+import socket
+import os
 import gtk_meshtastic_client.maps_marker as maps_marker
+import gtk_meshtastic_client.utils as utils
+import atexit
 
 @Gtk.Template(resource_path='/org/kop316/meshtastic/ui/maps_page.ui')
 class MapsPageBin(Adw.Bin):
@@ -41,7 +46,55 @@ class MapsPageBin(Adw.Bin):
     def define_latitude_last_seen(self, latitude):
         self.latitude_last_seen = latitude
 
-    def load_own_node_lat_long(self, lat, lng):
+    def close_gps_socket(self):
+        socket_path = os.environ['XDG_RUNTIME_DIR'] + "/meshtastic-gnss.sock"
+        if not hasattr(self, 'server'):
+            self.logger.debug("GPS Socket not active")
+            try:
+                os.remove(socket_path)
+            except FileNotFoundError:
+                pass
+            return
+
+        self.server.close()
+        try:
+            os.remove(socket_path)
+        except FileNotFoundError:
+            pass
+
+    def create_gps_socket(self):
+        if hasattr(self, 'server'):
+            self.logger.debug("GPS Socket already active")
+            return
+
+        socket_path = os.environ['XDG_RUNTIME_DIR'] + "/meshtastic-gnss.sock"
+
+        try:
+            os.remove(socket_path)
+        except FileNotFoundError:
+            pass
+
+        self.server = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
+        self.server.bind(socket_path)
+        self.server.listen()
+        self.server.setblocking(False)
+
+    def load_own_node_lat_long(self, lat, lng, alt):
+        app = Gtk.Application.get_default()
+
+        if app.app_settings.get_create_gps_socket():
+            self.create_gps_socket()
+
+            msgsp = utils.gga_sentence_builder(lat, lng, alt)
+
+            try:
+                conn, addr = self.server.accept()
+                conn.sendmsg([msgsp.encode("utf-8")])
+            except BlockingIOError:
+                pass
+            except BrokenPipeError:
+                pass
+
         self.own_node_latitude = lat
         self.own_node_longitude = lng
 
@@ -98,3 +151,11 @@ class MapsPageBin(Adw.Bin):
 
         self.marker_layer = Shumate.MarkerLayer.new(viewport)
         self.simple_map.add_overlay_layer(self.marker_layer)
+
+        if app.app_settings.get_create_gps_socket():
+            self.create_gps_socket()
+
+        atexit.register(self.cleanup)
+
+    def cleanup(self):
+        self.close_gps_socket()
