@@ -386,7 +386,7 @@ class MessageStorage():
         cur.close()
         con.close()
 
-    def update_direct_message(self, node_to_check):
+    def update_direct_message_chat(self, node_to_check):
         app = Gtk.Application.get_default()
         win = Gtk.Application.get_active_window(app)
         con = sqlite3.connect(self.database_name)
