@@ -99,6 +99,47 @@ def getTimeAgoDate(ts):
 def getUnixTimestampNow():
     return int(datetime.now(timezone.utc).timestamp())
 
+def gga_sentence_builder(lat, lng, alt):
+    degrees_lat = abs(lat)
+    degrees_lat, minutes_lat = divmod(degrees_lat * 60, 60)
+    degrees_lat = int(degrees_lat * 100)
+
+    degrees_lon = abs(lng)
+    degrees_lon, minutes_lon = divmod(degrees_lon * 60, 60)
+    degrees_lon = int(degrees_lon * 100)
+
+    nmea = "$" + "GN" + "GGA" + ","
+    nmea = nmea + str(datetime.utcnow().strftime("%H%M%S.%f")[0:9]) + ","
+
+    nmea = nmea + str(f"{degrees_lat + minutes_lat:.5f}".zfill(10)) + ","
+    nmea = nmea + ("S" if lat < 0 else "N") + ","
+
+    nmea = nmea + str(f"{degrees_lon + minutes_lon:.5f}".zfill(11)) + ","
+    nmea = nmea + ("W" if lng < 0 else "E") + ","
+
+    # GPS Quality
+    nmea = nmea + "1" + ","
+    # Satelites
+    nmea = nmea +  "0,"
+    # HDOP
+    nmea = nmea + "0,"
+    # Altitude
+    nmea = nmea + str(alt) + ","
+    # AltVal
+    nmea = nmea + "M" + ","
+    # Geoidal separation
+    nmea = nmea + "," + "M,"
+    # Differential corrections
+    nmea = nmea + "," + ","
+    nmea = nmea + "*"
+
+    cksum = 0
+    for sub in nmea:
+        cksum ^= ord(sub)
+    nmea = nmea + f"{cksum:02X}"
+
+    return nmea
+
 class MsgDirection(Enum):
     In = 0
     Out = 1
